@@ -1,6 +1,6 @@
 import typer
 from pinger.cli.app.struct import app_sub
-from pinger.cli.infra.struct import infra_sub
+from pinger.cli.infra.struct import app as infra_sub
 
 cli = typer.Typer(no_args_is_help=True)
 
